/*******************************************************************************
Filename:       hal_lcd.h

Autor:          Onur Kayikci
                Texas Instruments Freising, Germany
Datum:          19.11.2009

Description:    This file contains the interface to the DOGXL160 LCD Service.

Processor:      MSP430F5529

*******************************************************************************/

/**************************************************************************************************
 *                                           INCLUDES
 **************************************************************************************************/
#include "hal_types.h"
#include "hal_lcd.h"
#include "hal_mcu.h"



#include "msp430x552x.h"


/**************************************************************************************************
 *                                          CONSTANTS
 **************************************************************************************************/



                uint8  font5x7int[]={                 /* USCI Font Table 7x5 Font Size */
               0x00, 0x00, 0x00, 0x00, 0x00,          /* Each Row describes a 7x5 Font */
               0x00, 0x00, 0x00, 0x00, 0x00,          /* Each element in a row describes 7 (8) Column Pixels */
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0xFE, 0x00, 0x00, 0x00, 0x00,
               0xFE, 0xFE, 0x00, 0x00, 0x00,
               0xFE, 0xFE, 0xFE, 0x00, 0x00,
               0xFE, 0xFE, 0xFE, 0xFE, 0x00,
               0xFE, 0xFE, 0xFE, 0xFE, 0xFE,
               0x00, 0xFE, 0xFE, 0xFE, 0xFE,
               0x00, 0x00, 0xFE, 0xFE, 0xFE,
               0x00, 0x00, 0x00, 0xFE, 0xFE,
               0x00, 0x00, 0x00, 0x00, 0xFE,
               0x06, 0x0E, 0xFC, 0x40, 0x38,
               0xC0, 0xCC, 0x12, 0x12, 0x12,
               0xC0, 0xDE, 0x14, 0x14, 0x10,
               0x20, 0x30, 0x38, 0x30, 0x20,
               0x00, 0x7C, 0x38, 0x10, 0x00,
               0x00, 0x10, 0x38, 0x7C, 0x00,
               0x08, 0x18, 0x38, 0x18, 0x08,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x00, 0x00, 0xF2, 0x00, 0x00,
               0x00, 0xE0, 0x00, 0xE0, 0x00,
               0x28, 0xFE, 0x28, 0xFE, 0x28,
               0x24, 0x54, 0xFE, 0x54, 0x48,
               0xC4, 0xC8, 0x10, 0x26, 0x46,
               0x6C, 0x92, 0xAA, 0x44, 0x0A,
               0x00, 0xA0, 0xC0, 0x00, 0x00,
               0x00, 0x38, 0x44, 0x82, 0x00,
               0x00, 0x82, 0x44, 0x38, 0x00,
               0x28, 0x10, 0x7C, 0x10, 0x28,
               0x10, 0x10, 0x7C, 0x10, 0x10,
               0x00, 0x0A, 0x0C, 0x00, 0x00,
               0x10, 0x10, 0x10, 0x10, 0x10,
               0x00, 0x06, 0x06, 0x00, 0x00,
               0x04, 0x08, 0x10, 0x20, 0x40,
               0x7C, 0x8A, 0x92, 0xA2, 0x7C,
               0x00, 0x42, 0xFE, 0x02, 0x00,
               0x42, 0x86, 0x8A, 0x92, 0x62,
               0x84, 0x82, 0xA2, 0xD2, 0x8C,
               0x18, 0x28, 0x48, 0xFE, 0x08,
               0xE4, 0xA2, 0xA2, 0xA2, 0x9C,
               0x3C, 0x52, 0x92, 0x92, 0x0C,
               0x80, 0x8E, 0x90, 0xA0, 0xC0,
               0x6C, 0x92, 0x92, 0x92, 0x6C,
               0x60, 0x92, 0x92, 0x94, 0x78,
               0x00, 0x6C, 0x6C, 0x00, 0x00,
               0x00, 0x6A, 0x6C, 0x00, 0x00,
               0x10, 0x28, 0x44, 0x82, 0x00,
               0x28, 0x28, 0x28, 0x28, 0x28,
               0x00, 0x82, 0x44, 0x28, 0x10,
               0x40, 0x80, 0x8A, 0x90, 0x60,
               0x4C, 0x92, 0x9E, 0x82, 0x7C,
               0x7E, 0x88, 0x88, 0x88, 0x7E,
               0xFE, 0x92, 0x92, 0x92, 0x6C,
               0x7C, 0x82, 0x82, 0x82, 0x44,
               0xFE, 0x82, 0x82, 0x44, 0x38,
               0xFE, 0x92, 0x92, 0x92, 0x82,
               0xFE, 0x90, 0x90, 0x90, 0x80,
               0x7C, 0x82, 0x92, 0x92, 0x5E,
               0xFE, 0x10, 0x10, 0x10, 0xFE,
               0x00, 0x82, 0xFE, 0x82, 0x00,
               0x04, 0x02, 0x82, 0xFC, 0x80,
               0xFE, 0x10, 0x28, 0x44, 0x82,
               0xFE, 0x02, 0x02, 0x02, 0x02,
               0xFE, 0x40, 0x30, 0x40, 0xFE,
               0xFE, 0x20, 0x10, 0x08, 0xFE,
               0x7C, 0x82, 0x82, 0x82, 0x7C,
               0xFE, 0x90, 0x90, 0x90, 0x60,
               0x7C, 0x82, 0x8A, 0x84, 0x7A,
               0xFE, 0x90, 0x98, 0x94, 0x62,
               0x62, 0x92, 0x92, 0x92, 0x8C,
               0x80, 0x80, 0xFE, 0x80, 0x80,
               0xFC, 0x02, 0x02, 0x02, 0xFC,
               0xF8, 0x04, 0x02, 0x04, 0xF8,
               0xFC, 0x02, 0x1C, 0x02, 0xFC,
               0xC6, 0x28, 0x10, 0x28, 0xC6,
               0xE0, 0x10, 0x0E, 0x10, 0xE0,
               0x86, 0x8A, 0x92, 0xA2, 0xC2,
               0x00, 0xFE, 0x82, 0x82, 0x00,
               0xA8, 0x68, 0x3E, 0x68, 0xA8,
               0x00, 0x82, 0x82, 0xFE, 0x00,
               0x20, 0x40, 0x80, 0x40, 0x20,
               0x02, 0x02, 0x02, 0x02, 0x02,
               0x00, 0x80, 0x40, 0x20, 0x00,
               0x04, 0x2A, 0x2A, 0x2A, 0x1E,
               0xFE, 0x0A, 0x12, 0x12, 0x0C,
               0x1C, 0x22, 0x22, 0x22, 0x04,
               0x0C, 0x12, 0x12, 0x0A, 0xFE,
               0x1C, 0x2A, 0x2A, 0x2A, 0x18,
               0x10, 0x7E, 0x90, 0x80, 0x40,
               0x30, 0x4A, 0x4A, 0x4A, 0x7C,
               0xFE, 0x10, 0x20, 0x20, 0x1E,
               0x00, 0x00, 0x5E, 0x00, 0x00,
               0x04, 0x02, 0x22, 0xBC, 0x00,
               0xFE, 0x08, 0x14, 0x22, 0x00,
               0x00, 0x82, 0xFE, 0x02, 0x00,
               0x3E, 0x20, 0x18, 0x20, 0x1E,
               0x3E, 0x10, 0x20, 0x20, 0x1E,
               0x1C, 0x22, 0x22, 0x22, 0x1C,
               0x3E, 0x28, 0x28, 0x28, 0x10,
               0x10, 0x28, 0x28, 0x18, 0x3E,
               0x3E, 0x10, 0x20, 0x20, 0x10,
               0x12, 0x2A, 0x2A, 0x2A, 0x04,
               0x20, 0xFC, 0x22, 0x02, 0x04,
               0x3C, 0x02, 0x02, 0x04, 0x3E,
               0x38, 0x04, 0x02, 0x04, 0x38,
               0x3C, 0x02, 0x0C, 0x02, 0x3C,
               0x22, 0x14, 0x08, 0x14, 0x22,
               0x30, 0x0A, 0x0A, 0x0A, 0x3C,
               0x22, 0x26, 0x2A, 0x32, 0x22,
               0x00, 0x10, 0x6C, 0x82, 0x00,
               0x00, 0x00, 0xFE, 0x00, 0x00,
               0x00, 0x82, 0x6C, 0x10, 0x00,
               0x10, 0x10, 0x54, 0x38, 0x10,
               0x10, 0x38, 0x54, 0x10, 0x10,
               0x0E, 0x94, 0x24, 0x94, 0x0E,
               0x0E, 0x14, 0xA4, 0x14, 0x0E,
               0x0E, 0x54, 0xA4, 0x54, 0x0E,
               0x04, 0x2A, 0x6A, 0xAA, 0x1E,
               0x04, 0x2A, 0xAA, 0x2A, 0x1E,
               0xFE, 0xFE, 0x92, 0x92, 0x92,
               0xBC, 0x42, 0x42, 0x42, 0xBC,
               0x0C, 0x52, 0x12, 0x52, 0x0C,
               0x3A, 0x4C, 0x54, 0x64, 0xB8,
               0x18, 0x26, 0x3C, 0x64, 0x18,
               0xBC, 0x02, 0x02, 0x02, 0xBC,
               0x1C, 0x42, 0x02, 0x44, 0x1E,
               0x40, 0x20, 0x10, 0x08, 0x04,
               0x2A, 0x2C, 0x38, 0x68, 0xA8,
               0x30, 0x40, 0x30, 0x08, 0x30,
               0x52, 0xAA, 0xAA, 0xAA, 0x94,
               0x7E, 0x90, 0xFE, 0x90, 0x90,
               0x2C, 0x2A, 0x1C, 0x2A, 0x1A,
               0x12, 0x7E, 0x92, 0x92, 0x42,
               0xFE, 0xA0, 0xA8, 0x5E, 0x0A,
               0x38, 0x7C, 0x7C, 0x7C, 0x38,
               0x38, 0x44, 0x44, 0x44, 0x38,
               0x10, 0x38, 0x7C, 0x38, 0x10,
               0x10, 0x28, 0x44, 0x28, 0x10,
               0x00, 0x00, 0xEE, 0x00, 0x00,
               0x70, 0x8A, 0x8C, 0x88, 0x88,
               0x06, 0x0A, 0x12, 0x22, 0x7E,
               0x02, 0x22, 0x52, 0x8A, 0x02,
               0x02, 0x8A, 0x52, 0x22, 0x02,
               0x08, 0x1C, 0x2A, 0x08, 0xF8,
               0x20, 0x40, 0xFE, 0x40, 0x20,
               0x08, 0x04, 0xFE, 0x04, 0x08,
               0x00, 0x00, 0x00, 0x00, 0x00,
               0x0E, 0x0A, 0x0E, 0x00, 0x00,
               0x00, 0x00, 0xF0, 0x80, 0x80,
               0x02, 0x02, 0x1E, 0x00, 0x00,
               0x08, 0x04, 0x02, 0x00, 0x00,
               0x00, 0x18, 0x18, 0x00, 0x00,
               0x50, 0x50, 0x52, 0x54, 0x78,
               0x20, 0x22, 0x2C, 0x28, 0x30,
               0x04, 0x08, 0x1E, 0x20, 0x00,
               0x18, 0x10, 0x32, 0x12, 0x1C,
               0x12, 0x12, 0x1E, 0x12, 0x12,
               0x12, 0x14, 0x18, 0x3E, 0x10,
               0x10, 0x3E, 0x10, 0x14, 0x18,
               0x02, 0x12, 0x12, 0x1E, 0x02,
               0x2A, 0x2A, 0x2A, 0x3E, 0x00,
               0x18, 0x00, 0x1A, 0x02, 0x1C,
               0x10, 0x10, 0x10, 0x10, 0x10,
               0x80, 0x82, 0xBC, 0x90, 0xE0,
               0x08, 0x10, 0x3E, 0x40, 0x80,
               0x70, 0x40, 0xC2, 0x44, 0x78,
               0x42, 0x42, 0x7E, 0x42, 0x42,
               0x44, 0x48, 0x50, 0xFE, 0x40,
               0x42, 0xFC, 0x40, 0x42, 0x7C,
               0x50, 0x50, 0xFE, 0x50, 0x50,
               0x10, 0x62, 0x42, 0x44, 0x78,
               0x20, 0xC0, 0x42, 0x7C, 0x40,
               0x42, 0x42, 0x42, 0x42, 0x7E,
               0x40, 0xF2, 0x44, 0xF8, 0x40,
               0x52, 0x52, 0x02, 0x04, 0x38,
               0x42, 0x44, 0x48, 0x54, 0x62,
               0x40, 0xFC, 0x42, 0x52, 0x62,
               0x60, 0x12, 0x02, 0x04, 0x78,
               0x10, 0x62, 0x52, 0x4C, 0x78,
               0x50, 0x52, 0x7C, 0x90, 0x10,
               0x70, 0x00, 0x72, 0x04, 0x78,
               0x20, 0xA2, 0xBC, 0xA0, 0x20,
               0x00, 0xFE, 0x10, 0x08, 0x00,
               0x22, 0x24, 0xF8, 0x20, 0x20,
               0x02, 0x42, 0x42, 0x42, 0x02,
               0x42, 0x54, 0x48, 0x54, 0x60,
               0x44, 0x48, 0xDE, 0x68, 0x44,
               0x00, 0x02, 0x04, 0xF8, 0x00,
               0x1E, 0x00, 0x40, 0x20, 0x1E, 
               0xFC, 0x22, 0x22, 0x22, 0x22, 
               0x40, 0x42, 0x42, 0x44, 0x78, 
               0x20, 0x40, 0x20, 0x10, 0x0C, 
               0x4C, 0x40, 0xFE, 0x40, 0x4C,
               0x40, 0x48, 0x44, 0x4A, 0x70,
               0x00, 0x54, 0x54, 0x54, 0x02,
               0x1C, 0x24, 0x44, 0x04, 0x0E,
               0x02, 0x14, 0x08, 0x14, 0x60,
               0x50, 0x7C, 0x52, 0x52, 0x52, 
               0x20, 0xFE, 0x20, 0x28, 0x30, 
               0x02, 0x42, 0x42, 0x7E, 0x02,
               0x52, 0x52, 0x52, 0x52, 0x7E,
               0x20, 0xA0, 0xA2, 0xA4, 0x38,
               0xF0, 0x02, 0x04, 0xF8, 0x00,
               0x3E, 0x00, 0x7E, 0x02, 0x0C, 
               0x7E, 0x02, 0x04, 0x08, 0x10, 
               0x7E, 0x42, 0x42, 0x42, 0x7E, 
               0x70, 0x40, 0x42, 0x44, 0x78, 
               0x42, 0x42, 0x02, 0x04, 0x18,
               0x40, 0x20, 0x80, 0x40, 0x00, 
               0xE0, 0xA0, 0xE0, 0x00, 0x00, 
               0x1C, 0x22, 0x12, 0x0C, 0x32, 
               0x04, 0xAA, 0x2A, 0xAA, 0x1E, 
               0x3E, 0x54, 0x54, 0x54, 0x28, 
               0x14, 0x2A, 0x2A, 0x22, 0x04, 
               0x7E, 0x08, 0x08, 0x10, 0x78,
               0x1C, 0x22, 0x32, 0x2A, 0x24, 
               0x1E, 0x28, 0x48, 0x48, 0x30, 
               0x10, 0x2A, 0x2A, 0x2A, 0x3C,
               0x04, 0x02, 0x3C, 0x20, 0x20,
               0x40, 0x40, 0x00, 0xE0, 0x00,
               0x04, 0x02, 0x22, 0xBC, 0x00,
               0xA0, 0x40, 0xA0, 0x00, 0x00,
               0x18, 0x24, 0x7E, 0x24, 0x08,
               0x28, 0xFE, 0x2A, 0x02, 0x02,
               0x3E, 0x90, 0xA0, 0xA0, 0x1E,
               0x1C, 0xA2, 0x22, 0xA2, 0x1C, 
               0x7E, 0x28, 0x48, 0x48, 0x30,
               0x30, 0x48, 0x48, 0x28, 0x7E, 
               0x3C, 0x52, 0x52, 0x52, 0x3C, 
               0x0C, 0x14, 0x08, 0x14, 0x18, 
               0x1A, 0x26, 0x20, 0x26, 0x1A,
               0x3C, 0x82, 0x02, 0x84, 0x3E,
               0xC6, 0xAA, 0x92, 0x82, 0x82, 
               0x22, 0x3C, 0x20, 0x3E, 0x22, 
               0xA2, 0x94, 0x88, 0x94, 0xA2, 
               0x30, 0x0A, 0x0A, 0x0A, 0x3C, 
               0x28, 0x28, 0x3E, 0x28, 0x48, 
               0x22, 0x3C, 0x28, 0x28, 0x2E, 
               0x3E, 0x28, 0x38, 0x28, 0x3E, 
               0x10, 0x10, 0x54, 0x10, 0x10, 
               0x00, 0x00, 0x00, 0x00, 0x00, 
               0xFE, 0xFE, 0xFE, 0xFE, 0xFE};






/**************************************************************************************************
 *                                           MACROS
 **************************************************************************************************/

        uint8 LcdInitMacro[]={                                /* DogXL160 Initialization Commands */
                              Set_Com_End_H,                 
                              Set_Com_End_L,                 
                              Set_LCD_Mapping_Control,       
                              Set_Scroll_Line_LSB,           
                              Set_Scroll_Line_MSB,           
                              Set_Panel_Loading,             
                              Set_LCD_Bias_Ratio,            
                              Set_Vbias_Potentiometer_H,     
                              Set_Vbias_Potentiometer_L,
                              Set_RAM_Address_Control,
                              Set_Display_Enable,            
                              };

      




/**************************************************************************************************
 *                                       GLOBAL VARIABLES
 **************************************************************************************************/
                             

/**************************************************************************************************
 *                                       FUNCTIONS - API
 **************************************************************************************************/

void HalLcd_Clean(void);
void HalLcd_Init(void);
void HalLcd_AllPixelsOn(void);
void HalLcd_Rst(void);
void HalLcd_Write(uint8 row, uint8 col, uint16 f );
void HalLcd_WriteString (uint8 y, uint8 x, char word[]);
void HalLcd_SendCmd(uint8* SCmd, uint8 i);
void HalLcd_SendData(uint8* SData, uint8 i);
void HalLCD_SetPageAddress(uint8 PA);
void HalLCD_SetColumnAdress(uint8 CA);



/**************************************************************************************************
 * @fn      HalLcdInit
 *
 * @brief   Initilize LCD Service
 *
 * @param   init - pointer to void that contains the initialized value
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_Init(void)
{

  P3DIR |=  CD;                             
  P3OUT &= ~CD;                                 /* CD Low */
  HalLcd_SendCmd(LcdInitMacro, 11);
  
}


/**************************************************************************************************
 * @fn      HalLcd_SendCmd
 *
 * @brief   Sends commands to LCD via 3 wire SPI 
 *
 * @param   uint8* SCmd[] - Pointer to the commands to be written to the LCD
 *          uint i        - Number of the commands  to be written to the LCD       
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_SendCmd(uint8* SCmd, uint8 i)
{
  P3OUT &= ~CD;                                 /* CD Low */
  SPI_A0_Send_Data(SCmd , i);
}


/**************************************************************************************************
 * @fn      HalLcd_SendData
 *
 * @brief   Sends  Data to LCD via 3 wire SPI
 *
 * @param   uint8* SData - Pointer to the Data to be written to the LCD
 *          uint i       - Number of the  Datas  to be written to the LCD
 *
 * @return  None
 **************************************************************************************************/

void HalLcd_SendData(uint8* SData, uint8 i)

{
  P3OUT |=  CD;                                 /* CD High */
  SPI_A0_Send_Data(SData , i);
}


/**************************************************************************************************
 * @fn      HalLcd_SetPageAddress
 *
 * @brief   Sets Page Address of the LCD RAM memory 
 *
 * @param   uint8 PA - Page Address of the LCD RAM memory to be written
 *
 * @return  None
 **************************************************************************************************/
void HalLCD_SetPageAddress(uint8 PA)
{
  uint8 Cmd[] = {Page_Address + PA};  /* Page Adress Command = Page Address Initial Command + Page Address */
  HalLcd_SendCmd(Cmd, 1);
}


/**************************************************************************************************
 * @fn      HalLcd_SetColumnAdress
 *
 * @brief   Sets Column Address of the LCD RAM memory
 *
 * @param   uint8 CA - Column Address of the LCD RAM memory to be written
 *
 * @return  None
 **************************************************************************************************/
void HalLCD_SetColumnAdress(uint8 CA)
{
  uint8 H = 0x00;
  uint8 L = 0x00;
  uint8 ColumnAddress[]  = {Column_LSB0 , Column_MSB0 };
  L = (CA & 0x0F);                /* Seperate Command Adress to low and high   */
  H = (CA & 0xF0);
  H = (H >> 4);
  ColumnAddress[0] = (Column_LSB0 + L );    /* Column Adress CommandLSB = Column Address Initial Command */
                                            /*  + Column Address bits 0..3 */
  ColumnAddress[1] = (Column_MSB0 + H );    /* Column Adress CommandMSB = Column Address Initial Command */
                                            /*  + Column Address bits 4..7 */
  HalLcd_SendCmd(ColumnAddress, 2);
}

/**************************************************************************************************
 * @fn      HalLcd_AllPixelsOn
 *
 * @brief   Sets all Pixels on
 *
 * @param   None
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_AllPixelsOn(void)
{
  uint8 Cmd[] = {Set_All_Pixels_On};
  P3OUT &= ~CD;                                   /* CD Low */
  HalLcd_SendCmd(Cmd, 1);
  
}

/**************************************************************************************************
 * @fn      HalLcd_Rst
 *
 * @brief   System Reset
 *
 * @param   None
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_Rst(void)
{
  uint8 Cmd[] = {System_Reset};
  P3OUT &= ~CD;                                   /* CD Low */
  HalLcd_SendCmd(Cmd, 1);
  
}

/**************************************************************************************************
 * @fn      HalLcd_Clean
 *
 * @brief   Sets All pixels Off
 *
 * @param   None
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_Clean(void)
{
  uint8 LcdData[] = {0x00};
 
  for(uint8 p=0; p<26; p++){                  /* 25  Pages */
    for(uint8 c=0; c<160; c++){               /* 160 Columns */
      HalLCD_SetPageAddress(0x00 + p);
      HalLCD_SetColumnAdress(0x00 + c);       
      HalLcd_SendData(LcdData, 1);
    }
  }
}

/**************************************************************************************************
 * @fn      HalLcd_Write
 *
 * @brief   Writes a font from font5x7int[] Array to the LCD
 *
 * @param   uint8 row -   Page Address
 *          uint8 col -   Column Address
 *          uint16 f  -   Pointer to the font to be written to the LCD
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_Write(uint8 row, uint8 col, uint16 f )
{                                           /* Each Font consists of 5 Columns of 2 Pages */
                                            /* Each Page presents 4 pixels */
    uint8 LcdData[2];                       /* Pointer to the both pages of a column  */  
    uint8* ptr;
    uint8 H = 0x00;
    uint8 L = 0x00;
   
      for(uint8 c=0; c<5; c++){             /* Font Block Size 5 Columns */
                                           
      L = (font5x7int[f + c] & 0x0F);       /* LSB 4 Pixels are saved to L */     
      H = (font5x7int[f + c] & 0xF0);       /* MSB 4 Pixels are saved to H */
      H = (H >> 4);
      LcdData[0] = 0x00;
      LcdData[1] = 0x00;
      if((H & 0x01) == 0x01){               /* Each Pixel in the H is converted to 2 Bits, 11 Pixel On - 00 Pixel Off    */
        LcdData[0] = LcdData[0] + 0xC0;
      };
    
     if((H & 0x02) == 0x02){
        LcdData[0] = LcdData[0] + 0x30;
      };
   
     if((H & 0x04) == 0x04){
        LcdData[0] = LcdData[0] + 0x0C;
      };
  
    
     if((H & 0x08) == 0x08){
       LcdData[0] = LcdData[0] + 0x03;
      };
    
    
     if((L & 0x01) == 0x01){                /* Each Pixel in the L is converted to 2 Bits,  11 Pixel On - 00 Pixel Off  */
        LcdData[1] = LcdData[1] + 0xC0;
      };
    
     if((L & 0x02) == 0x02){
        LcdData[1] = LcdData[1] + 0x30;
      };
   
     if((L & 0x04) == 0x04){
        LcdData[1] = LcdData[1] + 0x0C;
      };
  
    
     if((L & 0x08) == 0x08){
        LcdData[1] = LcdData[1] + 0x03;
      };
    
      for(uint8 p=0; p<2; p++){                   /* Font Page Size 2 Pages */
        ptr = LcdData+p;
        HalLCD_SetPageAddress(0x00 + p + row);
        HalLCD_SetColumnAdress(0x00 + c + col);
        HalLcd_SendData(ptr, 1);                  /* A Column that consists of two Pages is sent to the LCD  */
       }
    }
}

/**************************************************************************************************
 * @fn      HalLcd_WriteString
 *
 * @brief   Writes a String to the LCD
 *
 * @param   uint8 y       -   Page Address
 *          uint8 x       -   Column Address
 *          char world[]  -   Pointer to the String to be written to the LCD
 *
 * @return  None
 **************************************************************************************************/
void HalLcd_WriteString (uint8 y, uint8 x, char word[]){
           uint8 k;
           uint8 a = 0;
           
           do{                     /* Writes a font to a block of 8x5 Pixels */
           k = word[a];
           HalLcd_Write( y, x, 5*k );
           x = x + 6;              /* Points to the next Block */
           a++;
           k = word[a];
           }while(k!=0);           /* Writes until the end of the String */
}



/*************************************************************************************************/
/*************************************************************************************************/